@@ -5,7 +5,7 @@ import click
 
 from pdm.cli import actions
 from pdm.cli.commands.base import BaseCommand
-from pdm.cli.options import sections_group
+from pdm.cli.options import install_group, sections_group
 from pdm.project import Project
 
 
@@ -14,6 +14,7 @@ class Command(BaseCommand):
 
     def add_arguments(self, parser: argparse.ArgumentParser) -> None:
         sections_group.add_to_parser(parser)
+        install_group.add_to_parser(parser)
         parser.add_argument(
             "--no-lock",
             dest="lock",
@@ -27,9 +28,12 @@ class Command(BaseCommand):
             actions.ask_for_import(project)
 
         if options.lock:
-            if not project.lockfile_file.exists():
+            if not (
+                project.lockfile_file.exists() and project.is_lockfile_compatible()
+            ):
                 project.core.ui.echo(
-                    "Lock file does not exist, trying to generate one..."
+                    "Lock file does not exist or is incompatible, "
+                    "trying to generate one..."
                 )
                 actions.do_lock(project, strategy="all")
             elif not project.is_lockfile_hash_match():
@@ -38,5 +42,10 @@ class Command(BaseCommand):
                 )
                 actions.do_lock(project, strategy="reuse")
         actions.do_sync(
-            project, options.sections, options.dev, options.default, False, False
+            project,
+            sections=options.sections,
+            dev=options.dev,
+            default=options.default,
+            no_editable=options.no_editable,
+            no_self=options.no_self,
         )
