@@ -2,13 +2,12 @@ from __future__ import annotations
 
 import argparse
 import os
-from argparse import Action
+from argparse import Action, _ArgumentGroup
 from collections import ChainMap
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Iterable, Mapping, MutableMapping, cast
 
 import atoml
-import cfonts
 from packaging.specifiers import SpecifierSet
 from pip._vendor.pkg_resources import Distribution
 from resolvelib.structs import DirectedGraph
@@ -29,6 +28,25 @@ if TYPE_CHECKING:
 
 
 class PdmFormatter(argparse.HelpFormatter):
+    def start_section(self, heading: str | None) -> None:
+        return super().start_section(
+            termui.yellow(heading.title() if heading else heading, bold=True)
+        )
+
+    def _format_usage(
+        self,
+        usage: str,
+        actions: Iterable[Action],
+        groups: Iterable[_ArgumentGroup],
+        prefix: str | None,
+    ) -> str:
+        if prefix is None:
+            prefix = "Usage: "
+        result = super()._format_usage(usage, actions, groups, prefix)
+        if prefix:
+            return result.replace(prefix, termui.yellow(prefix, bold=True))
+        return result
+
     def _format_action(self, action: Action) -> str:
         # determine the required width and the entry label
         help_position = min(self._action_max_length + 2, self._max_help_position)
@@ -76,51 +94,6 @@ class PdmFormatter(argparse.HelpFormatter):
         return self._join_parts(parts)
 
 
-class PdmParser(argparse.ArgumentParser):
-    def format_help(self) -> str:
-        formatter = self._get_formatter()
-
-        if getattr(self, "is_root", False):
-            banner = (
-                cfonts.render(
-                    "PDM",
-                    font="slick",
-                    gradient=["bright_red", "bright_green"],
-                    space=False,
-                )
-                + "\n"
-            )
-            formatter._add_item(lambda x: x, [banner])
-            self._positionals.title = "Commands"
-        self._optionals.title = "Options"
-        # description
-        formatter.add_text(self.description)
-
-        # usage
-        formatter.add_usage(
-            self.usage or "",
-            self._actions,
-            self._mutually_exclusive_groups,
-            prefix=termui.yellow("Usage", bold=True) + ": ",
-        )
-
-        # positionals, optionals and user-defined groups
-        for action_group in self._action_groups:
-            formatter.start_section(
-                termui.yellow(action_group.title, bold=True)
-                if action_group.title
-                else None
-            )
-            formatter.add_text(action_group.description)
-            formatter.add_arguments(action_group._group_actions)
-            formatter.end_section()
-
-        # epilog
-        formatter.add_text(self.epilog)
-        # determine help from format above
-        return formatter.format_help()
-
-
 class Package:
     """An internal class for the convenience of dependency graph building."""
 
@@ -307,6 +280,7 @@ def _format_forward_dependency_graph(project: Project, graph: DirectedGraph) ->
             required = str(all_dependencies[package.name].specifier or "Any")
         elif (
             not project.environment.is_global
+            and project.meta.name
             and package.name == project.meta.project_name.lower()
         ):
             required = "This project"
@@ -435,13 +409,12 @@ def set_env_in_reg(env_name: str, value: str) -> None:
         with winreg.OpenKey(root, "Environment", 0, winreg.KEY_ALL_ACCESS) as env_key:
             try:
                 old_value, type_ = winreg.QueryValueEx(env_key, env_name)
-                if value in [
-                    os.path.normcase(item) for item in old_value.split(os.pathsep)
-                ]:
+                paths = [os.path.normcase(item) for item in old_value.split(os.pathsep)]
+                if value in paths:
                     return
             except FileNotFoundError:
-                old_value, type_ = "", winreg.REG_EXPAND_SZ
-            new_value = os.pathsep.join([old_value, value]) if old_value else value
+                paths, type_ = [], winreg.REG_EXPAND_SZ
+            new_value = os.pathsep.join([value] + paths)
             winreg.SetValueEx(env_key, env_name, 0, type_, new_value)
 
 
@@ -457,7 +430,7 @@ def format_resolution_impossible(err: ResolutionImpossible) -> str:
     result.append(
         "Please make sure the package names are correct. If so, you can either "
         "loosen the version constraints of these dependencies, or "
-        "set a narrower `requires-python` range in the pyproject.toml."
+        "set a narrower `requires-python` range in the pyproject.tomli."
     )
     return "\n".join(result)
 
@@ -506,4 +479,4 @@ def merge_dictionary(
         elif isinstance(value, dict):
             target[key].update(value)
         elif isinstance(value, list):
-            target[key].extend(value)
+            target[key].extend(atoml.item(v) for v in value)
