@@ -2,26 +2,32 @@ from __future__ import annotations
 
 import argparse
 import importlib
+import itertools
 import os
 import pkgutil
 import sys
+from pathlib import Path
 from typing import Any, List, Optional, Type, cast
 
 import click
-from pip._vendor import pkg_resources
 from resolvelib import Resolver
 
 from pdm import termui
 from pdm.cli.actions import migrate_pyproject, print_pep582_command
 from pdm.cli.commands.base import BaseCommand
 from pdm.cli.options import ignore_python_option, pep582_option, verbose_option
-from pdm.cli.utils import PdmFormatter, PdmParser
+from pdm.cli.utils import PdmFormatter
 from pdm.exceptions import PdmUsageError
 from pdm.installers import Synchronizer
 from pdm.models.repositories import PyPIRepository
 from pdm.project import Project
 from pdm.project.config import Config, ConfigItem
 
+if sys.version_info >= (3, 8):
+    import importlib.metadata as importlib_metadata
+else:
+    import importlib_metadata
+
 COMMANDS_MODULE_PATH: str = importlib.import_module(
     "pdm.cli.commands"
 ).__path__  # type: ignore
@@ -31,11 +37,10 @@ class Core:
     """A high level object that manages all classes and configurations"""
 
     def __init__(self) -> None:
-        if sys.version_info >= (3, 8):
-            import importlib.metadata as importlib_metadata
-        else:
-            import importlib_metadata
-        self.version = importlib_metadata.version(__name__.split(".")[0])
+        try:
+            self.version = importlib_metadata.version(__name__.split(".")[0])
+        except importlib_metadata.PackageNotFoundError:
+            self.version = "UNKNOWN"
 
         self.project_class = Project
         self.repository_class = PyPIRepository
@@ -43,14 +48,15 @@ class Core:
         self.synchronizer_class = Synchronizer
 
         self.ui = termui.UI()
-        self.parser: Optional[PdmParser] = None
+        self.parser: Optional[argparse.ArgumentParser] = None
         self.subparsers: Optional[argparse._SubParsersAction] = None
 
     def init_parser(self) -> None:
-        self.parser = PdmParser(
+        self.parser = argparse.ArgumentParser(
             prog="pdm",
             description="PDM - Python Development Master",
             formatter_class=PdmFormatter,
+            usage="pdm [OPTIONS] [COMMANDS] ...",
         )
         self.parser.is_root = True  # type: ignore
         self.parser.add_argument(
@@ -62,6 +68,7 @@ class Core:
             ),
             help="show the version and exit",
         )
+        self.parser._positionals.title = "Commands"
         verbose_option.add_to_parser(self.parser)
         ignore_python_option.add_to_parser(self.parser)
         pep582_option.add_to_parser(self.parser)
@@ -100,7 +107,7 @@ class Core:
         migrate_pyproject(options.project)
 
     def create_project(
-        self, root_path: Optional[os.PathLike] = None, is_global: bool = False
+        self, root_path: str | Path | None = None, is_global: bool = False
     ) -> Project:
         return self.project_class(self, root_path, is_global)
 
@@ -175,7 +182,10 @@ class Core:
             ...
 
         """
-        for plugin in pkg_resources.iter_entry_points("pdm"):  # type: ignore
+        entry_points = importlib_metadata.entry_points()
+        for plugin in itertools.chain(
+            entry_points.get("pdm", []), entry_points.get("pdm.plugin", [])
+        ):
             plugin.load()(self)
 
 
