@@ -5,7 +5,7 @@ import multiprocessing
 import traceback
 from concurrent.futures._base import Future
 from concurrent.futures.thread import ThreadPoolExecutor
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union, cast
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 from pip._vendor.pkg_resources import Distribution
 
@@ -327,9 +327,11 @@ class Synchronizer:
                 self_candidate = self.environment.project.make_self_candidate(
                     not self.no_editable
                 )
-                self_key = cast(str, self_candidate.req.key)
+                self_key = self.self_key
+                assert self_key
                 self.candidates[self_key] = self_candidate
-                self.ui.echo("Installing the project as an editable package...")
+                word = "a" if self.no_editable else "an editable"
+                self.ui.echo(f"Installing the project as {word} package...")
                 with self.ui.indent("  "):
                     if self_key in self.working_set:
                         self.update_candidate(self_key)
