@@ -13,7 +13,6 @@ import sys
 import tempfile
 import urllib.parse as parse
 from contextlib import contextmanager
-from os import PathLike
 from pathlib import Path
 from re import Match
 from typing import (
@@ -29,7 +28,6 @@ from typing import (
     overload,
 )
 
-from distlib.wheel import Wheel
 from pip._vendor.packaging.tags import Tag
 from pip._vendor.pkg_resources import safe_name
 from pip._vendor.requests import Session
@@ -38,7 +36,9 @@ from pdm._types import Source
 from pdm.models.pip_shims import (
     InstallCommand,
     InstallRequirement,
+    Link,
     PackageFinder,
+    PipWheel,
     get_package_finder,
     url_to_path,
 )
@@ -147,7 +147,7 @@ def create_tracked_tempdir(
 
 
 def parse_name_version_from_wheel(filename: str) -> tuple[str, str]:
-    w = Wheel(filename)
+    w = PipWheel(os.path.basename(filename))
     return w.name, w.version
 
 
@@ -298,7 +298,7 @@ def get_in_project_venv_python(root: Path) -> Path | None:
 
 @contextmanager
 def atomic_open_for_write(
-    filename: PathLike, *, encoding: str = "utf-8"
+    filename: str | Path, *, encoding: str = "utf-8"
 ) -> Iterator[TextIO]:
     fd, name = tempfile.mkstemp("-atomic-write", "pdm-")
     fp = open(fd, "w", encoding=encoding)
@@ -306,7 +306,6 @@ def atomic_open_for_write(
         yield fp
     except Exception:
         fp.close()
-        os.unlink(name)
         raise
     else:
         fp.close()
@@ -314,11 +313,16 @@ def atomic_open_for_write(
             os.unlink(filename)
         except OSError:
             pass
-        shutil.move(name, filename)
+        # The tempfile is created with mode 600, we need to restore the default mode
+        # with copyfile() instead of move().
+        # See: https://github.com/pdm-project/pdm/issues/542
+        shutil.copyfile(name, str(filename))
+    finally:
+        os.unlink(name)
 
 
 @contextmanager
-def cd(path: str) -> Iterator:
+def cd(path: str | Path) -> Iterator:
     _old_cwd = os.getcwd()
     os.chdir(path)
     try:
@@ -366,14 +370,15 @@ def populate_link(
     finder: PackageFinder,
     ireq: InstallRequirement,
     upgrade: bool = False,
-) -> None:
+) -> Link | None:
     """Populate ireq's link attribute"""
     if not ireq.link:
         candidate = finder.find_requirement(ireq, upgrade)
         if not candidate:
-            return
+            return None
         link = getattr(candidate, "link", candidate)
         ireq.link = link
+    return ireq.link
 
 
 _VT = TypeVar("_VT")
@@ -423,7 +428,7 @@ def path_replace(pattern: str, replace_with: str, dest: str) -> str:
     )
 
 
-def is_venv_python(interpreter: os.PathLike) -> bool:
+def is_venv_python(interpreter: str | Path) -> bool:
     """Check if the given interpreter path is from a virtualenv"""
     interpreter = Path(interpreter)
     if interpreter.parent.parent.joinpath("pyvenv.cfg").exists():
@@ -439,7 +444,7 @@ def is_venv_python(interpreter: os.PathLike) -> bool:
     return False
 
 
-def find_python_in_path(path: os.PathLike) -> Path | None:
+def find_python_in_path(path: str | Path) -> Path | None:
     """Find a python interpreter from the given path, the input argument could be:
 
     - A valid path to the interpreter
