@@ -3,11 +3,8 @@ import sys
 import venv
 from pathlib import Path
 
-import distlib.wheel
 import pytest
 
-from pdm.models.requirements import filter_requirements_with_extras
-from pdm.pep517.api import build_wheel
 from pdm.utils import cd, temp_environ
 
 
@@ -26,13 +23,17 @@ def test_project_python_with_pyenv_support(project, mocker):
             "pythonfinder.models.python.get_python_version",
             return_value="3.8.0",
         )
-        assert Path(project.python.executable) == pyenv_python
+        mocker.patch(
+            "pdm.models.python.get_underlying_executable", return_value=sys.executable
+        )
+        assert Path(project.python.path) == pyenv_python
+        assert project.python.executable == Path(sys.executable).as_posix()
 
         # Clean cache
         project._python = None
 
         project.project_config["python.use_pyenv"] = False
-        assert Path(project.python.executable) != pyenv_python
+        assert Path(project.python.path) != pyenv_python
 
 
 def test_project_config_items(project):
@@ -88,20 +89,6 @@ def test_project_use_venv(project):
     assert env.is_global
 
 
-def test_project_with_combined_extras(fixture_project):
-    project = fixture_project("demo-combined-extras")
-    (project.root / "build").mkdir(exist_ok=True)
-    with cd(project.root.as_posix()):
-        wheel_name = build_wheel(str(project.root / "build"))
-        wheel = distlib.wheel.Wheel(str(project.root / "build" / wheel_name))
-
-    all_requires = filter_requirements_with_extras(
-        wheel.metadata.run_requires, ("all",)
-    )
-    for dep in ("urllib3", "chardet", "idna"):
-        assert dep in all_requires
-
-
 def test_project_packages_path(project):
     packages_path = project.environment.packages_path
     version = ".".join(map(str, sys.version_info[:2]))
